%bcond_with bootstrap

Name:           opentest4j
Version:        1.3.0
Release:        %mkrel 2
Group:          Development/Java
Summary:        Open Test Alliance for the JVM
License:        Apache-2.0
URL:            https://github.com/ota4j-team/opentest4j
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

Source0:        https://github.com/ota4j-team/opentest4j/archive/r%{version}.tar.gz
Source100:      https://repo1.maven.org/maven2/org/opentest4j/opentest4j/%{version}/opentest4j-%{version}.pom

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
%endif

%description
Open Test Alliance for the JVM is a minimal common foundation for
testing libraries on the JVM.  The primary goal of the project is to
enable testing frameworks like JUnit, TestNG, Spock, etc. and
third-party assertion libraries like Hamcrest, AssertJ, etc. to use a
common set of exceptions that IDEs and build tools can support in a
consistent manner across all testing scenarios -- for example, for
consistent handling of failed assertions and failed assumptions as
well as visualization of test execution in IDEs and reports.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n opentest4j-r%{version}
find -name \*.jar -delete
cp -p %{SOURCE100} pom.xml

mv src/module/java/* src/main/java

%pom_add_dep junit:junit::test

%pom_xpath_inject pom:project "
  <build>
    <pluginManagement>
      <plugins>
        <plugin>
          <artifactId>maven-jar-plugin</artifactId>
          <configuration>
            <archive>
              <manifestEntries>
                <Implementation-Title>opentest4j</Implementation-Title>
                <Implementation-Vendor>opentest4j.org</Implementation-Vendor>
                <Implementation-Version>%{version}</Implementation-Version>
                <Specification-Title>opentest4j</Specification-Title>
                <Specification-Vendor>opentest4j.org</Specification-Vendor>
                <Specification-Version>%{version}</Specification-Version>
                <!-- OSGi metadata required by Eclipse -->
                <Bundle-ManifestVersion>2</Bundle-ManifestVersion>
                <Bundle-SymbolicName>org.opentest4j</Bundle-SymbolicName>
                <Bundle-Version>%{version}</Bundle-Version>
                <Export-Package>org.opentest4j;version=\"%{version}\"</Export-Package>
              </manifestEntries>
            </archive>
          </configuration>
        </plugin>
        <plugin>
          <groupId>org.apache.maven.plugins</groupId>
          <artifactId>maven-compiler-plugin</artifactId>
          <executions>
            <execution>
              <id>default-compile</id>
              <goals>
                <goal>compile</goal>
              </goals>
              <configuration>
                <release>8</release>
                <excludes>
                  <exclude>**/module-info.java</exclude>
                </excludes>
              </configuration>
            </execution>
            <execution>
              <id>module-info</id>
              <goals>
                <goal>compile</goal>
              </goals>
              <configuration>
                <release>9</release>
                <includes>
                  <include>**/module-info.java</include>
                </includes>
              </configuration>
            </execution>
            <execution>
              <id>default-testCompile</id>
              <goals>
                <goal>testCompile</goal>
              </goals>
              <configuration>
                <release>11</release>
              </configuration>
            </execution>
          </executions>
        </plugin>
      </plugins>
    </pluginManagement>
  </build>"

# Fix unused reference to unused dependency
# This is fixed upstream: https://github.com/ota4j-team/opentest4j/commit/70d3d54f2cd076a962e81d9510e6716f3cbf8060
sed -i -e '/org\.apache\.commons\.codec/d' src/test/java/org/opentest4j/AssertionFailedErrorTests.java

%build
%mvn_build

%install
%mvn_install

%files -f .mfiles
%license LICENSE
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE



%changelog
* Mon May 27 2024 ns80 <ns80> 1.3.0-2.mga10
+ Revision: 2068259
- rebuild for java 21

* Thu Sep 14 2023 daviddavid <daviddavid> 1.3.0-1.mga10
+ Revision: 1986500
- Update to upstream version 1.3.0

* Mon Jul 25 2022 neoclust <neoclust> 1.2.0-12.mga9
+ Revision: 1871430
- Disable bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 1.2.0-11.mga9
+ Revision: 1870829
- Add a bootstrap mode
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Mar 07 2021 daviddavid <daviddavid> 1.2.0-3.mga9
+ Revision: 1700300
- Build with release flag

* Mon Sep 07 2020 daviddavid <daviddavid> 1.2.0-2.mga8
+ Revision: 1623254
- Rebuilt for JDK-11

* Mon Jul 27 2020 daviddavid <daviddavid> 1.2.0-1.mga8
+ Revision: 1609258
- Update to version 1.2.0

* Sat Feb 15 2020 umeabot <umeabot> 1.1.1-2.mga8
+ Revision: 1527615
- Mageia 8 Mass Rebuild

* Thu Jul 18 2019 daviddavid <daviddavid> 1.1.1-1.mga8
+ Revision: 1422442
- Update to latest upstream release 1.1.1

* Tue Dec 04 2018 guillomovitch <guillomovitch> 1.0.0-1.mga7
+ Revision: 1338199
- imported package opentest4j

